Crate astrid_plugins

Crate astrid_plugins 

Plugin trait and registry for the Astrid secure agent runtime SDK.

Provides the core abstractions for extending Astrid with plugins:

Tool Naming Convention

Plugin tools are exposed to the LLM as plugin:{plugin_id}:{tool_name}, which avoids collision with built-in tools (no colons) and MCP tools (server:tool — single colon).

Storage Isolation

Each plugin gets a ScopedKvStore pre-bound to the namespace plugin:{plugin_id}. Plugins cannot access each other’s data.

Re-exports

pub use context::PluginContext;
pub use context::PluginToolContext;
pub use discovery::discover_manifests;
pub use discovery::load_manifest;
pub use discovery::load_manifests_from_dir;
pub use error::PluginError;
pub use error::PluginResult;
pub use lockfile::IntegrityViolation;
pub use lockfile::LockedPlugin;
pub use lockfile::PluginLockfile;
pub use lockfile::PluginSource;
pub use manifest::PluginCapability;
pub use manifest::PluginEntryPoint;
pub use manifest::PluginManifest;
pub use mcp_plugin::McpPlugin;
pub use mcp_plugin::create_plugin;
pub use plugin::Plugin;
pub use plugin::PluginId;
pub use plugin::PluginState;
pub use registry::PluginRegistry;
pub use registry::PluginToolDefinition;
pub use sandbox::SandboxProfile;
pub use security::PluginSecurityGate;
pub use tool::PluginTool;
pub use wasm::WasmPlugin;
pub use wasm::WasmPluginLoader;
pub use wasm::WasmPluginTool;

Modules

context
Plugin context types.
discovery
Plugin manifest discovery from standard locations.
error
Plugin error types.
lockfile
Plugin lockfile for version pinning and integrity verification.
manifest
Plugin manifest types.
mcp_plugin
MCP-backed plugin implementation.
plugin
Plugin trait and core types.
registry
Plugin registry.
sandbox
OS-level sandbox profiles for plugin MCP server processes.
security
Security gate trait for plugin host function calls.
tool
Plugin tool trait.
wasm
WASM plugin runtime powered by Extism.