pub struct PluginContext {
pub workspace_root: PathBuf,
pub kv: ScopedKvStore,
pub config: HashMap<String, Value>,
}Expand description
Context provided to a plugin during lifecycle operations (load/unload).
Contains the information a plugin needs to initialize itself.
Fields
workspace_root: PathBufThe workspace root directory.
kv: ScopedKvStorePre-scoped KV store for this plugin (plugin:{plugin_id} namespace).
config: HashMap<String, Value>Plugin configuration from the manifest.
Implementations
Sourceimpl PluginContext
impl PluginContext
Sourcepub fn new(
workspace_root: PathBuf,
kv: ScopedKvStore,
config: HashMap<String, Value>,
) -> Self
pub fn new( workspace_root: PathBuf, kv: ScopedKvStore, config: HashMap<String, Value>, ) -> Self
Create a new plugin context.
Sourcepub fn for_testing(
plugin_id: &PluginId,
workspace_root: PathBuf,
) -> PluginResult<Self>
pub fn for_testing( plugin_id: &PluginId, workspace_root: PathBuf, ) -> PluginResult<Self>
Create a plugin context with a MemoryKvStore for testing.
Errors
Returns an error if the scoped KV store cannot be created.