pub fn create_plugin(
manifest: PluginManifest,
mcp_client: Option<McpClient>,
) -> PluginResult<Box<dyn Plugin>>Expand description
Create a plugin from a manifest, choosing the appropriate implementation based on the entry point type.
Errors
PluginError::McpClientRequiredif the entry point isMcpbut noMcpClientwas provided.PluginError::UnsupportedEntryPointif the entry point type is not supported (e.g.Wasm— handled by a different subsystem).